coef.glm: Coefficient and Bias From Generalized Linear Model Fit
Description
coef.glm is a S3 method computing the raw coefficients,
leading order bias, and bias corrected coefficients from a
generalized linear model (glm) fit.
Usage
# S3 method for glm
coef(object, type = c("raw", "bias", "corrected"), ...)
Value
A numeric vector of requested components.
When type='corrected', the 'bias' attribute
will be set to a numeric vector of estimated biases
being subtracted from the raw coefficients.
Arguments
object
An object with similar structure as returned from
glm.
type
A character scalar, being one of 'raw',
'bias', and 'corrected'. 'raw' returns the
usual coefficients; 'bias' returns the estimated leading order bias;
and 'corrected' returns the coefficients after subtracting
the estimated bias.